@@ -14,7 +14,7 @@
    **/
 
 
-   global $timeout_in_minutes, $allow_user_timeout_config;
+   global $timeout_in_minutes, $allow_user_timeout_config, $allow_user_disable;
 
 
    // this is the default timeout value for users who have not
@@ -30,4 +30,10 @@
    $allow_user_timeout_config = 1;
 
 
+   // set this to zero to prevent users from being able to 
+   // turn off/disable timeout functionality (only applicable
+   // when $allow_user_timeout_config is enabled)
+   //
+   $allow_user_disable = 1;
+
 ?>
